# frozen_string_literal: true

require 'elasticsearch'

module ElasticsearchHermes
  class << self
    attr_writer :configuration
  end

  def self.configuration
    @configuration ||= Configuration.new
  end

  def self.reset
    @configuration = Configuration.new
  end

  def self.setup
    yield(configuration)
  end

  def self.default_connect_options
    base_es_urls = configuration.es_url
    urls = base_es_urls.split(',').compact.uniq
    options = {
      url: urls,
      retry_on_failure: configuration.retry_on_failure,
      log: configuration.enable_logs
    }
    options
  end

  def self.client
    @client ||= ::Elasticsearch::Client.new(default_connect_options)
  end

  def self.fields
    configuration.fields
  end

  def self.connect!
    return unless client

    info = @client.info
    cluster_version = info['version']['number']
    msg = "Connected to Elastic version #{cluster_version}."
    Logger.log(msg)
  end

  def self.refresh
    client.indices.refresh
  end
end
